
/* Generated data (by glib-mkenums) */


/* --- bseexports.h --- */
#include	"bseexports.h"
/* BseExportNodeType
 */
static GEnumValue bse_export_node_type_values[] = {
  { BSE_EXPORT_NODE_NONE, "BSE_EXPORT_NODE_NONE", "none" },
  { BSE_EXPORT_NODE_LINK, "BSE_EXPORT_NODE_LINK", "link" },
  { BSE_EXPORT_NODE_ENUM, "BSE_EXPORT_NODE_ENUM", "enum" },
  { BSE_EXPORT_NODE_RECORD, "BSE_EXPORT_NODE_RECORD", "record" },
  { BSE_EXPORT_NODE_SEQUENCE, "BSE_EXPORT_NODE_SEQUENCE", "sequence" },
  { BSE_EXPORT_NODE_CLASS, "BSE_EXPORT_NODE_CLASS", "class" },
  { BSE_EXPORT_NODE_PROC, "BSE_EXPORT_NODE_PROC", "proc" },
  { 0, NULL, NULL }
};

/* --- gsldatacache.h --- */
#include	"gsldatacache.h"
/* GslDataCacheRequest
 */
static GEnumValue gsl_data_cache_request_values[] = {
  { GSL_DATA_CACHE_REQUEST, "GSL_DATA_CACHE_REQUEST", "request" },
  { GSL_DATA_CACHE_DEMAND_LOAD, "GSL_DATA_CACHE_DEMAND_LOAD", "demand-load" },
  { GSL_DATA_CACHE_PEEK, "GSL_DATA_CACHE_PEEK", "peek" },
  { 0, NULL, NULL }
};

/* --- gslvorbis-cutter.h --- */
#include	"gslvorbis-cutter.h"
/* GslVorbisCutterMode
 */
static GEnumValue gsl_vorbis_cutter_mode_values[] = {
  { GSL_VORBIS_CUTTER_NONE, "GSL_VORBIS_CUTTER_NONE", "none" },
  { GSL_VORBIS_CUTTER_SAMPLE_BOUNDARY, "GSL_VORBIS_CUTTER_SAMPLE_BOUNDARY", "sample-boundary" },
  { GSL_VORBIS_CUTTER_PACKET_BOUNDARY, "GSL_VORBIS_CUTTER_PACKET_BOUNDARY", "packet-boundary" },
  { GSL_VORBIS_CUTTER_PAGE_BOUNDARY, "GSL_VORBIS_CUTTER_PAGE_BOUNDARY", "page-boundary" },
  { 0, NULL, NULL }
};

/* --- bsebiquadfilter.h --- */
#include	"bsebiquadfilter.h"
/* BseBiquadFilterType
 */
static GEnumValue bse_biquad_filter_type_values[] = {
  { BSE_BIQUAD_FILTER_RESONANT_LOWPASS, "BSE_BIQUAD_FILTER_RESONANT_LOWPASS", "lowpass" },
  { BSE_BIQUAD_FILTER_RESONANT_HIGHPASS, "BSE_BIQUAD_FILTER_RESONANT_HIGHPASS", "highpass" },
  { 0, NULL, NULL }
};
/* BseBiquadFilterNorm
 */
static GEnumValue bse_biquad_filter_norm_values[] = {
  { BSE_BIQUAD_FILTER_NORM_PASSBAND, "BSE_BIQUAD_FILTER_NORM_PASSBAND", "passband" },
  { BSE_BIQUAD_FILTER_NORM_RESONANCE_GAIN, "BSE_BIQUAD_FILTER_NORM_RESONANCE_GAIN", "resonance-gain" },
  { BSE_BIQUAD_FILTER_NORM_PEAK_GAIN, "BSE_BIQUAD_FILTER_NORM_PEAK_GAIN", "peak-gain" },
  { 0, NULL, NULL }
};

/* --- bseenums.h --- */
#include	"bseenums.h"
/* BseRegistrationType
 */
static GEnumValue bse_registration_type_values[] = {
  { BSE_REGISTER_PLUGIN, "BSE_REGISTER_PLUGIN", "plugin" },
  { BSE_REGISTER_SCRIPT, "BSE_REGISTER_SCRIPT", "script" },
  { BSE_REGISTER_DONE, "BSE_REGISTER_DONE", "done" },
  { 0, NULL, NULL }
};
/* BseInterpolType
 */
static GEnumValue bse_interpol_type_values[] = {
  { BSE_INTERPOL_NONE, "BSE_INTERPOL_NONE", "None" },
  { BSE_INTERPOL_LINEAR, "BSE_INTERPOL_LINEAR", "Linear" },
  { BSE_INTERPOL_CUBIC, "BSE_INTERPOL_CUBIC", "Cubic" },
  { 0, NULL, NULL }
};
/* BseLoopType
 */
static GEnumValue bse_loop_type_values[] = {
  { BSE_LOOP_NONE, "BSE_LOOP_NONE", "none" },
  { BSE_LOOP_PATTERN, "BSE_LOOP_PATTERN", "pattern" },
  { BSE_LOOP_PATTERN_ROWS, "BSE_LOOP_PATTERN_ROWS", "pattern-rows" },
  { BSE_LOOP_SONG, "BSE_LOOP_SONG", "song" },
  { 0, NULL, NULL }
};
/* BseMagicFlags
 */
static GFlagsValue bse_magic_flags_values[] = {
  { BSE_MAGIC_BSE_BIN_EXTENSION, "BSE_MAGIC_BSE_BIN_EXTENSION", "bin-extension" },
  { BSE_MAGIC_BSE_SONG, "BSE_MAGIC_BSE_SONG", "song" },
  { 0, NULL, NULL }
};
/* BseErrorType
 */
static GEnumValue bse_error_type_values[] = {
  { BSE_ERROR_NONE, "BSE_ERROR_NONE", "none" },
  { BSE_ERROR_INTERNAL, "BSE_ERROR_INTERNAL", "internal" },
  { BSE_ERROR_UNKNOWN, "BSE_ERROR_UNKNOWN", "unknown" },
  { BSE_ERROR_IO, "BSE_ERROR_IO", "io" },
  { BSE_ERROR_PERMS, "BSE_ERROR_PERMS", "perms" },
  { BSE_ERROR_FILE_BUSY, "BSE_ERROR_FILE_BUSY", "file-busy" },
  { BSE_ERROR_FILE_EXISTS, "BSE_ERROR_FILE_EXISTS", "file-exists" },
  { BSE_ERROR_FILE_EOF, "BSE_ERROR_FILE_EOF", "file-eof" },
  { BSE_ERROR_FILE_EMPTY, "BSE_ERROR_FILE_EMPTY", "file-empty" },
  { BSE_ERROR_FILE_NOT_FOUND, "BSE_ERROR_FILE_NOT_FOUND", "file-not-found" },
  { BSE_ERROR_FILE_IS_DIR, "BSE_ERROR_FILE_IS_DIR", "file-is-dir" },
  { BSE_ERROR_FILE_OPEN_FAILED, "BSE_ERROR_FILE_OPEN_FAILED", "file-open-failed" },
  { BSE_ERROR_FILE_SEEK_FAILED, "BSE_ERROR_FILE_SEEK_FAILED", "file-seek-failed" },
  { BSE_ERROR_FILE_READ_FAILED, "BSE_ERROR_FILE_READ_FAILED", "file-read-failed" },
  { BSE_ERROR_FILE_WRITE_FAILED, "BSE_ERROR_FILE_WRITE_FAILED", "file-write-failed" },
  { BSE_ERROR_MANY_FILES, "BSE_ERROR_MANY_FILES", "many-files" },
  { BSE_ERROR_NO_FILES, "BSE_ERROR_NO_FILES", "no-files" },
  { BSE_ERROR_NO_SPACE, "BSE_ERROR_NO_SPACE", "no-space" },
  { BSE_ERROR_NO_MEMORY, "BSE_ERROR_NO_MEMORY", "no-memory" },
  { BSE_ERROR_NO_HEADER, "BSE_ERROR_NO_HEADER", "no-header" },
  { BSE_ERROR_NO_SEEK_INFO, "BSE_ERROR_NO_SEEK_INFO", "no-seek-info" },
  { BSE_ERROR_NO_DATA, "BSE_ERROR_NO_DATA", "no-data" },
  { BSE_ERROR_DATA_CORRUPT, "BSE_ERROR_DATA_CORRUPT", "data-corrupt" },
  { BSE_ERROR_WRONG_N_CHANNELS, "BSE_ERROR_WRONG_N_CHANNELS", "wrong-n-channels" },
  { BSE_ERROR_FORMAT_INVALID, "BSE_ERROR_FORMAT_INVALID", "format-invalid" },
  { BSE_ERROR_FORMAT_UNKNOWN, "BSE_ERROR_FORMAT_UNKNOWN", "format-unknown" },
  { BSE_ERROR_DATA_UNMATCHED, "BSE_ERROR_DATA_UNMATCHED", "data-unmatched" },
  { BSE_ERROR_TEMP, "BSE_ERROR_TEMP", "temp" },
  { BSE_ERROR_WAVE_NOT_FOUND, "BSE_ERROR_WAVE_NOT_FOUND", "wave-not-found" },
  { BSE_ERROR_CODEC_FAILURE, "BSE_ERROR_CODEC_FAILURE", "codec-failure" },
  { BSE_ERROR_UNIMPLEMENTED, "BSE_ERROR_UNIMPLEMENTED", "unimplemented" },
  { BSE_ERROR_INVALID_PROPERTY, "BSE_ERROR_INVALID_PROPERTY", "invalid-property" },
  { BSE_ERROR_INVALID_MIDI_CONTROL, "BSE_ERROR_INVALID_MIDI_CONTROL", "invalid-midi-control" },
  { BSE_ERROR_PARSE_ERROR, "BSE_ERROR_PARSE_ERROR", "parse-error" },
  { BSE_ERROR_SPAWN, "BSE_ERROR_SPAWN", "spawn" },
  { BSE_ERROR_DEVICE_NOT_AVAILABLE, "BSE_ERROR_DEVICE_NOT_AVAILABLE", "device-not-available" },
  { BSE_ERROR_DEVICE_ASYNC, "BSE_ERROR_DEVICE_ASYNC", "device-async" },
  { BSE_ERROR_DEVICE_BUSY, "BSE_ERROR_DEVICE_BUSY", "device-busy" },
  { BSE_ERROR_DEVICE_FORMAT, "BSE_ERROR_DEVICE_FORMAT", "device-format" },
  { BSE_ERROR_DEVICE_BUFFER, "BSE_ERROR_DEVICE_BUFFER", "device-buffer" },
  { BSE_ERROR_DEVICE_LATENCY, "BSE_ERROR_DEVICE_LATENCY", "device-latency" },
  { BSE_ERROR_DEVICE_CHANNELS, "BSE_ERROR_DEVICE_CHANNELS", "device-channels" },
  { BSE_ERROR_DEVICE_FREQUENCY, "BSE_ERROR_DEVICE_FREQUENCY", "device-frequency" },
  { BSE_ERROR_DEVICES_MISMATCH, "BSE_ERROR_DEVICES_MISMATCH", "devices-mismatch" },
  { BSE_ERROR_SOURCE_NO_SUCH_MODULE, "BSE_ERROR_SOURCE_NO_SUCH_MODULE", "source-no-such-module" },
  { BSE_ERROR_SOURCE_NO_SUCH_ICHANNEL, "BSE_ERROR_SOURCE_NO_SUCH_ICHANNEL", "source-no-such-ichannel" },
  { BSE_ERROR_SOURCE_NO_SUCH_OCHANNEL, "BSE_ERROR_SOURCE_NO_SUCH_OCHANNEL", "source-no-such-ochannel" },
  { BSE_ERROR_SOURCE_NO_SUCH_CONNECTION, "BSE_ERROR_SOURCE_NO_SUCH_CONNECTION", "source-no-such-connection" },
  { BSE_ERROR_SOURCE_PRIVATE_ICHANNEL, "BSE_ERROR_SOURCE_PRIVATE_ICHANNEL", "source-private-ichannel" },
  { BSE_ERROR_SOURCE_ICHANNEL_IN_USE, "BSE_ERROR_SOURCE_ICHANNEL_IN_USE", "source-ichannel-in-use" },
  { BSE_ERROR_SOURCE_CHANNELS_CONNECTED, "BSE_ERROR_SOURCE_CHANNELS_CONNECTED", "source-channels-connected" },
  { BSE_ERROR_SOURCE_CONNECTION_INVALID, "BSE_ERROR_SOURCE_CONNECTION_INVALID", "source-connection-invalid" },
  { BSE_ERROR_SOURCE_PARENT_MISMATCH, "BSE_ERROR_SOURCE_PARENT_MISMATCH", "source-parent-mismatch" },
  { BSE_ERROR_SOURCE_BAD_LOOPBACK, "BSE_ERROR_SOURCE_BAD_LOOPBACK", "source-bad-loopback" },
  { BSE_ERROR_SOURCE_BUSY, "BSE_ERROR_SOURCE_BUSY", "source-busy" },
  { BSE_ERROR_SOURCE_TYPE_INVALID, "BSE_ERROR_SOURCE_TYPE_INVALID", "source-type-invalid" },
  { BSE_ERROR_PROC_NOT_FOUND, "BSE_ERROR_PROC_NOT_FOUND", "proc-not-found" },
  { BSE_ERROR_PROC_BUSY, "BSE_ERROR_PROC_BUSY", "proc-busy" },
  { BSE_ERROR_PROC_PARAM_INVAL, "BSE_ERROR_PROC_PARAM_INVAL", "proc-param-inval" },
  { BSE_ERROR_PROC_EXECUTION, "BSE_ERROR_PROC_EXECUTION", "proc-execution" },
  { BSE_ERROR_PROC_ABORT, "BSE_ERROR_PROC_ABORT", "proc-abort" },
  { BSE_ERROR_NO_ENTRY, "BSE_ERROR_NO_ENTRY", "no-entry" },
  { BSE_ERROR_NO_EVENT, "BSE_ERROR_NO_EVENT", "no-event" },
  { BSE_ERROR_NO_TARGET, "BSE_ERROR_NO_TARGET", "no-target" },
  { BSE_ERROR_NOT_OWNER, "BSE_ERROR_NOT_OWNER", "not-owner" },
  { BSE_ERROR_INVALID_OFFSET, "BSE_ERROR_INVALID_OFFSET", "invalid-offset" },
  { BSE_ERROR_INVALID_DURATION, "BSE_ERROR_INVALID_DURATION", "invalid-duration" },
  { BSE_ERROR_INVALID_OVERLAP, "BSE_ERROR_INVALID_OVERLAP", "invalid-overlap" },
  { 0, NULL, NULL }
};

/* --- bseglobals.h --- */
#include	"bseglobals.h"
/* BseTimeRangeType
 */
static GEnumValue bse_time_range_type_values[] = {
  { BSE_TIME_RANGE_SHORT, "BSE_TIME_RANGE_SHORT", "short" },
  { BSE_TIME_RANGE_MEDIUM, "BSE_TIME_RANGE_MEDIUM", "medium" },
  { BSE_TIME_RANGE_LONG, "BSE_TIME_RANGE_LONG", "long" },
  { 0, NULL, NULL }
};

/* --- bsemidievent.h --- */
#include	"bsemidievent.h"
/* BseMidiEventType
 */
static GEnumValue bse_midi_event_type_values[] = {
  { BSE_MIDI_NOTE_OFF, "BSE_MIDI_NOTE_OFF", "note-off" },
  { BSE_MIDI_NOTE_ON, "BSE_MIDI_NOTE_ON", "note-on" },
  { BSE_MIDI_KEY_PRESSURE, "BSE_MIDI_KEY_PRESSURE", "key-pressure" },
  { BSE_MIDI_CONTROL_CHANGE, "BSE_MIDI_CONTROL_CHANGE", "control-change" },
  { BSE_MIDI_PROGRAM_CHANGE, "BSE_MIDI_PROGRAM_CHANGE", "program-change" },
  { BSE_MIDI_CHANNEL_PRESSURE, "BSE_MIDI_CHANNEL_PRESSURE", "channel-pressure" },
  { BSE_MIDI_PITCH_BEND, "BSE_MIDI_PITCH_BEND", "pitch-bend" },
  { BSE_MIDI_SYS_EX, "BSE_MIDI_SYS_EX", "sys-ex" },
  { BSE_MIDI_SONG_POINTER, "BSE_MIDI_SONG_POINTER", "song-pointer" },
  { BSE_MIDI_SONG_SELECT, "BSE_MIDI_SONG_SELECT", "song-select" },
  { BSE_MIDI_TUNE, "BSE_MIDI_TUNE", "tune" },
  { BSE_MIDI_END_EX, "BSE_MIDI_END_EX", "end-ex" },
  { BSE_MIDI_TIMING_CLOCK, "BSE_MIDI_TIMING_CLOCK", "timing-clock" },
  { BSE_MIDI_SONG_START, "BSE_MIDI_SONG_START", "song-start" },
  { BSE_MIDI_SONG_CONTINUE, "BSE_MIDI_SONG_CONTINUE", "song-continue" },
  { BSE_MIDI_SONG_STOP, "BSE_MIDI_SONG_STOP", "song-stop" },
  { BSE_MIDI_ACTIVE_SENSING, "BSE_MIDI_ACTIVE_SENSING", "active-sensing" },
  { BSE_MIDI_SYSTEM_RESET, "BSE_MIDI_SYSTEM_RESET", "system-reset" },
  { BSE_MIDI_SEQUENCE_NUMBER, "BSE_MIDI_SEQUENCE_NUMBER", "sequence-number" },
  { BSE_MIDI_TEXT_EVENT, "BSE_MIDI_TEXT_EVENT", "text-event" },
  { BSE_MIDI_COPYRIGHT_NOTICE, "BSE_MIDI_COPYRIGHT_NOTICE", "copyright-notice" },
  { BSE_MIDI_TRACK_NAME, "BSE_MIDI_TRACK_NAME", "track-name" },
  { BSE_MIDI_INSTRUMENT_NAME, "BSE_MIDI_INSTRUMENT_NAME", "instrument-name" },
  { BSE_MIDI_LYRIC, "BSE_MIDI_LYRIC", "lyric" },
  { BSE_MIDI_MARKER, "BSE_MIDI_MARKER", "marker" },
  { BSE_MIDI_CUE_POINT, "BSE_MIDI_CUE_POINT", "cue-point" },
  { BSE_MIDI_TEXT_EVENT_08, "BSE_MIDI_TEXT_EVENT_08", "text-event-08" },
  { BSE_MIDI_TEXT_EVENT_09, "BSE_MIDI_TEXT_EVENT_09", "text-event-09" },
  { BSE_MIDI_TEXT_EVENT_0A, "BSE_MIDI_TEXT_EVENT_0A", "text-event-0a" },
  { BSE_MIDI_TEXT_EVENT_0B, "BSE_MIDI_TEXT_EVENT_0B", "text-event-0b" },
  { BSE_MIDI_TEXT_EVENT_0C, "BSE_MIDI_TEXT_EVENT_0C", "text-event-0c" },
  { BSE_MIDI_TEXT_EVENT_0D, "BSE_MIDI_TEXT_EVENT_0D", "text-event-0d" },
  { BSE_MIDI_TEXT_EVENT_0E, "BSE_MIDI_TEXT_EVENT_0E", "text-event-0e" },
  { BSE_MIDI_TEXT_EVENT_0F, "BSE_MIDI_TEXT_EVENT_0F", "text-event-0f" },
  { BSE_MIDI_CHANNEL_PREFIX, "BSE_MIDI_CHANNEL_PREFIX", "channel-prefix" },
  { BSE_MIDI_END_OF_TRACK, "BSE_MIDI_END_OF_TRACK", "end-of-track" },
  { BSE_MIDI_SET_TEMPO, "BSE_MIDI_SET_TEMPO", "set-tempo" },
  { BSE_MIDI_SMPTE_OFFSET, "BSE_MIDI_SMPTE_OFFSET", "smpte-offset" },
  { BSE_MIDI_TIME_SIGNATURE, "BSE_MIDI_TIME_SIGNATURE", "time-signature" },
  { BSE_MIDI_KEY_SIGNATURE, "BSE_MIDI_KEY_SIGNATURE", "key-signature" },
  { BSE_MIDI_SEQUENCER_SPECIFIC, "BSE_MIDI_SEQUENCER_SPECIFIC", "sequencer-specific" },
  { BSE_MIDI_MULTI_SYS_EX_START, "BSE_MIDI_MULTI_SYS_EX_START", "multi-sys-ex-start" },
  { BSE_MIDI_MULTI_SYS_EX_NEXT, "BSE_MIDI_MULTI_SYS_EX_NEXT", "multi-sys-ex-next" },
  { BSE_MIDI_X_CONTINUOUS_CHANGE, "BSE_MIDI_X_CONTINUOUS_CHANGE", "x-continuous-change" },
  { 0, NULL, NULL }
};

/* --- bseproject.h --- */
#include	"bseproject.h"
/* BseProjectState
 */
static GEnumValue bse_project_state_values[] = {
  { BSE_PROJECT_INACTIVE, "BSE_PROJECT_INACTIVE", "inactive" },
  { BSE_PROJECT_ACTIVE, "BSE_PROJECT_ACTIVE", "active" },
  { BSE_PROJECT_PLAYING, "BSE_PROJECT_PLAYING", "playing" },
  { 0, NULL, NULL }
};

/* --- bsestandardosc.h --- */
#include	"bsestandardosc.h"
/* BseStandardOscWaveType
 */
static GEnumValue bse_standard_osc_wave_type_values[] = {
  { BSE_STANDARD_OSC_SINE, "BSE_STANDARD_OSC_SINE", "Sine" },
  { BSE_STANDARD_OSC_TRIANGLE, "BSE_STANDARD_OSC_TRIANGLE", "Triangle" },
  { BSE_STANDARD_OSC_SAW_RISE, "BSE_STANDARD_OSC_SAW_RISE", "Rising Saw" },
  { BSE_STANDARD_OSC_SAW_FALL, "BSE_STANDARD_OSC_SAW_FALL", "Falling Saw" },
  { BSE_STANDARD_OSC_PEAK_RISE, "BSE_STANDARD_OSC_PEAK_RISE", "Rising Peak" },
  { BSE_STANDARD_OSC_PEAK_FALL, "BSE_STANDARD_OSC_PEAK_FALL", "Falling Peak" },
  { BSE_STANDARD_OSC_MOOG_SAW, "BSE_STANDARD_OSC_MOOG_SAW", "Moog Saw" },
  { BSE_STANDARD_OSC_SQUARE, "BSE_STANDARD_OSC_SQUARE", "Square" },
  { BSE_STANDARD_OSC_PULSE, "BSE_STANDARD_OSC_PULSE", "Pulse" },
  { 0, NULL, NULL }
};

/* --- bsemididecoder.h --- */
#include	"bsemididecoder.h"
/* BseMidiDecoderState
 */
static GEnumValue bse_midi_decoder_state_values[] = {
  { BSE_MIDI_DECODER_ZERO, "BSE_MIDI_DECODER_ZERO", "zero" },
  { BSE_MIDI_DECODER_DELTA_TIME, "BSE_MIDI_DECODER_DELTA_TIME", "delta-time" },
  { BSE_MIDI_DECODER_EVENT, "BSE_MIDI_DECODER_EVENT", "event" },
  { BSE_MIDI_DECODER_VLENGTH, "BSE_MIDI_DECODER_VLENGTH", "vlength" },
  { BSE_MIDI_DECODER_DATA, "BSE_MIDI_DECODER_DATA", "data" },
  { BSE_MIDI_DECODER_DONE, "BSE_MIDI_DECODER_DONE", "done" },
  { 0, NULL, NULL }
};

/* Generated data ends here */

